@@ -10,4 +10,4 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and limitations under the License.
 
-utils::globalVariables(c(":=", "name", "type", ".", ".data"))
+utils::globalVariables(c(":=", "name", "type", ".", ".data", "name_conversions", "Name", "Title", "Abstract", "metadataID"))
