@@ -14,8 +14,7 @@ geoserver_down <- !(check_geoserver(timeout = 5, quiet = TRUE))
 
 test_that("Check geoserver works", {
   skip_if_offline()
-  skip_on_cran()
-  skip_if(geoserver_down)
+  skip_if(geoserver_down, message = "VicmapR geoserver not currently available")
   
   expect_error(check_geoserver(timeout = 0.001))
   
